@@ -44,7 +44,10 @@ class GSPeerConnectionBroadcasterPi:
     def getMicrofonRelay(self):
         global relay, microfon
         if relay is None:
-            microfon = MediaPlayer("default", format="pulse")
+            microfon = MediaPlayer("hw:1", format="alsa", options={
+                "channels": "1",
+                "sample_rate": "44100"
+            })
             relay = MediaRelay()
         return relay.subscribe(microfon.audio)
 
@@ -110,7 +113,6 @@ class GSPeerConnectionBroadcasterPi:
                 self.peerConnections[id] = pc
 
                 video = self.getPiH264Relay()
-                audio = self.getMicrofonRelay()
 
                 @pc.on("connectionstatechange")
                 async def on_connectionstatechange():
@@ -120,17 +122,20 @@ class GSPeerConnectionBroadcasterPi:
                         self.peerConnections.pop(id, None)
 
                 transceiver = pc.addTransceiver("video", direction="sendonly")
-                transceiver1 = pc.addTransceiver("audio", direction="sendonly")
 
                 capabilities = RTCRtpSender.getCapabilities("video")
                 preferences = list(filter(lambda x: x.name == "H264", capabilities.codecs))
                 preferences += list(filter(lambda x: x.name == "rtx", capabilities.codecs))
                 transceiver.setCodecPreferences(preferences)
 
+                if self.gsdbs.credentials["audio"]:
+                    audio = self.getMicrofonRelay()
+                    transceiver1 = pc.addTransceiver("audio", direction="sendonly")
+
                 for t in pc.getTransceivers():
                     if t.kind == "video":
                         pc.addTrack(video)
-                    if t.kind == "audio":
+                    if audio is not None and t.kind == "audio":
                         pc.addTrack(audio)
 
                 await pc.setRemoteDescription(offer)
